@@ -26,6 +26,11 @@
  */
 package org.apache.http.impl.client.cache;
 
+import static org.easymock.EasyMock.expect;
+import static org.easymock.classextension.EasyMock.createNiceMock;
+import static org.easymock.classextension.EasyMock.replay;
+import static org.easymock.classextension.EasyMock.verify;
+
 import java.io.IOException;
 import java.util.Date;
 import java.util.HashMap;
@@ -41,14 +46,14 @@ import org.apache.http.HttpVersion;
 import org.apache.http.ProtocolVersion;
 import org.apache.http.client.cache.HttpCacheEntry;
 import org.apache.http.client.cache.HttpCacheStorage;
-import static org.apache.http.impl.cookie.DateUtils.formatDate;
-
+import org.apache.http.client.utils.DateUtils;
 import org.apache.http.message.BasicHeader;
 import org.apache.http.message.BasicHttpEntityEnclosingRequest;
 import org.apache.http.message.BasicHttpRequest;
 import org.apache.http.message.BasicHttpResponse;
-
-import static org.easymock.classextension.EasyMock.*;
+import org.easymock.EasyMock;
+import org.easymock.IAnswer;
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -71,11 +76,11 @@ public class TestCacheInvalidator {
     public void setUp() {
         now = new Date();
         tenSecondsAgo = new Date(now.getTime() - 10 * 1000L);
-        
+
         host = new HttpHost("foo.example.com");
-        mockStorage = createMock(HttpCacheStorage.class);
+        mockStorage = createNiceMock(HttpCacheStorage.class);
         cacheKeyGenerator = new CacheKeyGenerator();
-        mockEntry = createMock(HttpCacheEntry.class);
+        mockEntry = createNiceMock(HttpCacheEntry.class);
         request = HttpTestUtils.makeDefaultRequest();
         response = HttpTestUtils.make200Response();
 
@@ -97,7 +102,7 @@ public class TestCacheInvalidator {
     public void testInvalidatesRequestsThatArentGETorHEAD() throws Exception {
         request = new BasicHttpRequest("POST","/path", HTTP_1_1);
         final String theUri = "http://foo.example.com:80/path";
-        Map<String,String> variantMap = new HashMap<String,String>();
+        final Map<String,String> variantMap = new HashMap<String,String>();
         cacheEntryHasVariantMap(variantMap);
 
         cacheReturnsEntryForUri(theUri);
@@ -111,11 +116,11 @@ public class TestCacheInvalidator {
 
     @Test
     public void testInvalidatesUrisInContentLocationHeadersOnPUTs() throws Exception {
-        HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
+        final HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
         request.setEntity(HttpTestUtils.makeBody(128));
         request.setHeader("Content-Length","128");
 
-        String contentLocation = "http://foo.example.com/content";
+        final String contentLocation = "http://foo.example.com/content";
         request.setHeader("Content-Location", contentLocation);
 
         final String theUri = "http://foo.example.com:80/";
@@ -134,11 +139,11 @@ public class TestCacheInvalidator {
 
     @Test
     public void testInvalidatesUrisInLocationHeadersOnPUTs() throws Exception {
-        HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
+        final HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
         request.setEntity(HttpTestUtils.makeBody(128));
         request.setHeader("Content-Length","128");
 
-        String contentLocation = "http://foo.example.com/content";
+        final String contentLocation = "http://foo.example.com/content";
         request.setHeader("Location",contentLocation);
 
         final String theUri = "http://foo.example.com:80/";
@@ -157,11 +162,11 @@ public class TestCacheInvalidator {
 
     @Test
     public void testInvalidatesRelativeUrisInContentLocationHeadersOnPUTs() throws Exception {
-        HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
+        final HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
         request.setEntity(HttpTestUtils.makeBody(128));
         request.setHeader("Content-Length","128");
 
-        String relativePath = "/content";
+        final String relativePath = "/content";
         request.setHeader("Content-Location",relativePath);
 
         final String theUri = "http://foo.example.com:80/";
@@ -180,11 +185,11 @@ public class TestCacheInvalidator {
 
     @Test
     public void testDoesNotInvalidateUrisInContentLocationHeadersOnPUTsToDifferentHosts() throws Exception {
-        HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
+        final HttpEntityEnclosingRequest request = new BasicHttpEntityEnclosingRequest("PUT","/",HTTP_1_1);
         request.setEntity(HttpTestUtils.makeBody(128));
         request.setHeader("Content-Length","128");
 
-        String contentLocation = "http://bar.example.com/content";
+        final String contentLocation = "http://bar.example.com/content";
         request.setHeader("Content-Location",contentLocation);
 
         final String theUri = "http://foo.example.com:80/";
@@ -240,7 +245,7 @@ public class TestCacheInvalidator {
         final String theUri = "http://foo.example.com:80/";
         final String variantUri = "theVariantURI";
 
-        Map<String,String> mapOfURIs = new HashMap<String,String>();
+        final Map<String,String> mapOfURIs = new HashMap<String,String>();
         mapOfURIs.put(variantUri,variantUri);
 
         cacheReturnsEntryForUri(theUri);
@@ -257,7 +262,7 @@ public class TestCacheInvalidator {
     @Test
     public void testCacheFlushException() throws Exception {
         request = new BasicHttpRequest("POST","/",HTTP_1_1);
-        String theURI = "http://foo.example.com:80/";
+        final String theURI = "http://foo.example.com:80/";
 
         cacheReturnsExceptionForUri(theURI);
 
@@ -265,7 +270,7 @@ public class TestCacheInvalidator {
         impl.flushInvalidatedCacheEntries(host, request);
         verifyMocks();
     }
-    
+
     @Test
     public void doesNotFlushForResponsesWithoutContentLocation()
             throws Exception {
@@ -273,44 +278,73 @@ public class TestCacheInvalidator {
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
     @Test
     public void flushesEntryIfFresherAndSpecifiedByContentLocation()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
         mockStorage.removeEntry(theURI);
-        
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
+    @Test
+    public void flushesEntryIfFresherAndSpecifiedByLocation()
+            throws Exception {
+        response.setStatusCode(201);
+        response.setHeader("ETag","\"new-etag\"");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Location", theURI);
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
+           new BasicHeader("ETag", "\"old-etag\"")
+        });
+
+        expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
+        mockStorage.removeEntry(theURI);
+
+        replayMocks();
+        impl.flushInvalidatedCacheEntries(host, request, response);
+        verifyMocks();
+    }
+
     @Test
     public void doesNotFlushEntryForUnsuccessfulResponse()
             throws Exception {
         response = new BasicHttpResponse(HttpVersion.HTTP_1_1, HttpStatus.SC_BAD_REQUEST, "Bad Request");
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
@@ -320,18 +354,18 @@ public class TestCacheInvalidator {
     public void flushesEntryIfFresherAndSpecifiedByNonCanonicalContentLocation()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String cacheKey = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String cacheKey = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", "http://foo.example.com/bar");
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(cacheKey)).andReturn(entry).anyTimes();
         mockStorage.removeEntry(cacheKey);
-        
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
@@ -341,18 +375,18 @@ public class TestCacheInvalidator {
     public void flushesEntryIfFresherAndSpecifiedByRelativeContentLocation()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String cacheKey = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String cacheKey = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", "/bar");
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(cacheKey)).andReturn(entry).anyTimes();
         mockStorage.removeEntry(cacheKey);
-        
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
@@ -362,214 +396,253 @@ public class TestCacheInvalidator {
     public void doesNotFlushEntryIfContentLocationFromDifferentHost()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String cacheKey = "http://baz.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String cacheKey = "http://baz.example.com:80/bar";
         response.setHeader("Content-Location", cacheKey);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(cacheKey)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(cacheKey);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
 
-    
-    
+
+
     @Test
     public void doesNotFlushEntrySpecifiedByContentLocationIfEtagsMatch()
             throws Exception {
         response.setHeader("ETag","\"same-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"same-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
 
     @Test
-    public void doesNotFlushEntrySpecifiedByContentLocationIfNotNewer()
+    public void doesNotFlushEntrySpecifiedByContentLocationIfOlder()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(tenSecondsAgo));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(now)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(now)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
     @Test
     public void doesNotFlushEntryIfNotInCache()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(null).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
     @Test
     public void doesNotFlushEntrySpecifiedByContentLocationIfResponseHasNoEtag()
             throws Exception {
         response.removeHeaders("ETag");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
            new BasicHeader("ETag", "\"old-etag\"")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+        EasyMock.expectLastCall().andAnswer(new IAnswer<Void>() {
+            public Void answer() {
+                Assert.fail();
+                return null;
+              }
+          }).anyTimes();
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
     @Test
     public void doesNotFlushEntrySpecifiedByContentLocationIfEntryHasNoEtag()
             throws Exception {
         response.setHeader("ETag", "\"some-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("Date", formatDate(tenSecondsAgo)),
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
 
     @Test
-    public void doesNotFlushEntrySpecifiedByContentLocationIfResponseHasNoDate()
+    public void flushesEntrySpecifiedByContentLocationIfResponseHasNoDate()
             throws Exception {
         response.setHeader("ETag", "\"new-etag\"");
         response.removeHeaders("Date");
-        String theURI = "http://foo.example.com:80/bar";
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
                 new BasicHeader("ETag", "\"old-etag\""),
-                new BasicHeader("Date", formatDate(tenSecondsAgo)),
+                new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo)),
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
-        replayMocks();
-        impl.flushInvalidatedCacheEntries(host, request, response);
-        verifyMocks();
-    }
-    
-    @Test
-    public void doesNotFlushEntrySpecifiedByContentLocationIfEntryHasNoDate()
-            throws Exception {
-        response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
-        response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
-           new BasicHeader("ETag", "\"old-etag\"")
-        });
-        
-        expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
 
     @Test
-    public void doesNotFlushEntrySpecifiedByContentLocationIfResponseHasMalformedDate()
+    public void flushesEntrySpecifiedByContentLocationIfEntryHasNoDate()
+            throws Exception {
+        response.setHeader("ETag","\"new-etag\"");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Content-Location", theURI);
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
+           new BasicHeader("ETag", "\"old-etag\"")
+        });
+
+        expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
+        mockStorage.removeEntry(theURI);
+
+        replayMocks();
+        impl.flushInvalidatedCacheEntries(host, request, response);
+        verifyMocks();
+    }
+
+    @Test
+    public void flushesEntrySpecifiedByContentLocationIfResponseHasMalformedDate()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
         response.setHeader("Date", "blarg");
-        String theURI = "http://foo.example.com:80/bar";
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {                
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
                 new BasicHeader("ETag", "\"old-etag\""),
-                new BasicHeader("Date", formatDate(tenSecondsAgo))
+                new BasicHeader("Date", DateUtils.formatDate(tenSecondsAgo))
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
-    
+
     @Test
-    public void doesNotFlushEntrySpecifiedByContentLocationIfEntryHasMalformedDate()
+    public void flushesEntrySpecifiedByContentLocationIfEntryHasMalformedDate()
             throws Exception {
         response.setHeader("ETag","\"new-etag\"");
-        response.setHeader("Date", formatDate(now));
-        String theURI = "http://foo.example.com:80/bar";
+        response.setHeader("Date", DateUtils.formatDate(now));
+        final String theURI = "http://foo.example.com:80/bar";
         response.setHeader("Content-Location", theURI);
-        
-        HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {                
+
+        final HttpCacheEntry entry = HttpTestUtils.makeCacheEntry(new Header[] {
                 new BasicHeader("ETag", "\"old-etag\""),
                 new BasicHeader("Date", "foo")
         });
-        
+
         expect(mockStorage.getEntry(theURI)).andReturn(entry).anyTimes();
-        
+        mockStorage.removeEntry(theURI);
+
         replayMocks();
         impl.flushInvalidatedCacheEntries(host, request, response);
         verifyMocks();
     }
 
-    
+
     // Expectations
-    private void cacheEntryHasVariantMap(Map<String,String> variantMap) {
+    private void cacheEntryHasVariantMap(final Map<String,String> variantMap) {
         expect(mockEntry.getVariantMap()).andReturn(variantMap);
     }
 
-    private void cacheReturnsEntryForUri(String theUri) throws IOException {
+    private void cacheReturnsEntryForUri(final String theUri) throws IOException {
         expect(mockStorage.getEntry(theUri)).andReturn(mockEntry);
     }
 
-    private void cacheReturnsExceptionForUri(String theUri) throws IOException {
+    private void cacheReturnsExceptionForUri(final String theUri) throws IOException {
         expect(mockStorage.getEntry(theUri)).andThrow(
                 new IOException("TOTAL FAIL"));
     }
 
-    private void entryIsRemoved(String theUri) throws IOException {
+    private void entryIsRemoved(final String theUri) throws IOException {
         mockStorage.removeEntry(theUri);
     }
 
-}
\ No newline at end of file
+}
