@@ -229,6 +229,8 @@ public class TestURIUtils {
                 URIUtils.extractHost(new URI("http://localhost:8080;sessionid=stuff/abcd")));
         Assert.assertEquals(new HttpHost("localhost",-1),
                 URIUtils.extractHost(new URI("http://localhost:;sessionid=stuff/abcd")));
+        Assert.assertEquals(null,
+                URIUtils.extractHost(new URI("http://:80/robots.txt")));
     }
 
     @Test
